define([
    'jquery',
    'Magento_Checkout/js/checkout-data',
    'mage/translate'
], function($, checkoutData, $t) {
    "use strict";
    /*
     * Checkout Validations
     * The 'undefined' check if for M2 versions < 2.2 which load the validation before loading the page itself
    */
    return function(validator) {
        validator.addRule('validate-filoblu-firstname-lastname-sum-length', function(value, params, additionalParams) {
            if (params.prefix == 'billingAddress') {
                var e = (params.target).replace('billingAddress.', params.prefix + checkoutData.getSelectedPaymentMethod() + '.');
                params.target = e;
            }
            if (typeof $(params.target).val() === 'undefined') {
                return true;
            }
            else {
                // +1 character is for the space between fields
                return ((parseInt(value.length + $(params.target).val().length) + 1 <= parseInt(params.sumLength)) && (parseInt(value.length) <= parseInt(params.length)));
            }
        }, $.mage.__('The field characters count or the sum of firstname and lastname fields exceeds maximum characters.'));

        validator.addRule('validate-filoblu-street-sum-length', function(value, params, additionalParams) {
            if (params.prefix == 'billingAddress') {
                var e = (params.target).replace('billingAddress.', params.prefix + checkoutData.getSelectedPaymentMethod() + '.');
                params.target = e;
            }
            if (typeof $(params.target).val() === 'undefined') {
                return true;
            }
            else {
                // spaceBetweenFields: this is for counting spaces between street fields
                var spaceBetweenFields = 0;
                var streetsSum = 0;
                $(params.target).each(function(index, element) {
                    spaceBetweenFields += index != 0 ? $(element).val().length > 0 ? 1 : 0 : 0;
                    streetsSum += ($(element).val().length);
                });
                streetsSum += spaceBetweenFields;
                return streetsSum <= params.length;
            }
        }, $.mage.__('The sum of the street fields exceeds maximum characters.'));

        validator.addRule('validate-filoblu-company-street-sum-length', function(value, params, additionalParams) {
            if (params.prefix == 'billingAddress') {
                var e = (params.target).replace('billingAddress.', params.prefix + checkoutData.getSelectedPaymentMethod() + '.');
                params.target = e;
            }
            if (typeof $(params.target).val() === 'undefined') {
                return true;
            }
            else {
                // spaceBetweenFields: this is for counting spaces between street fields
                var company = ($('div[name^="' + params.prefix + '.company"] input[name="company"]'));
                if (params.prefix == 'billingAddress') {
                    company = ($('div[name^="' + params.prefix + checkoutData.getSelectedPaymentMethod() + '.company"] input[name="company"]'));
                }
                spaceBetweenFields = company.val().length > 0 ? 1 : 0;
                var streetsSum = company.val().length;
                $(params.target).each(function(index, element) {
                    spaceBetweenFields += index != 0 ? $(element).val().length > 0 ? 1 : 0 : 0;
                    streetsSum += ($(element).val().length);
                });
                streetsSum += spaceBetweenFields;
                return streetsSum <= params.length;
            }
        }, $.mage.__('The sum of the street fields (including company) exceeds maximum characters.'));

        validator.addRule('validate-filoblu-field-length', function(value, params, additionalParams) {
            if (params.prefix == 'billingAddress') {
                var e = (params.target).replace('billingAddress.', params.prefix + checkoutData.getSelectedPaymentMethod() + '.');
                params.target = e;
            }
            if (typeof ($(params.target).val()) === 'undefined') {
                return true;
            }
            else {
                return parseInt($(params.target).val().length) <= parseInt(params.length);
            }
        }, $.mage.__('The field exceeds maximum characters.'));

        return validator;
    };
});
